==> deb-installer_24.3.01.tar.xz: BUILD/translations/deb-installer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="118"/>
        <source>Install</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="90"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Die folgenden Pakete werden installiert.
Klicken Sie auf  &apos;Details anzeigen...&apos; für Informationen über die Pakete.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="98"/>
        <source>File: %1</source>
        <translation>Datei: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="115"/>
        <source>Will install the following:</source>
        <translation>Wird das Folgende installieren:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="130"/>
        <source>Installing selected package please authenticate</source>
        <translation>Installiere ausgewählte Pakete. Bitte authentifizieren...</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="136"/>
        <source>Press any key to close</source>
        <translation>Schließen mit beliebiger Taste</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Programm zur Installation von Debian-Binärpaketen (deb files)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>Dateien...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Name der zu installierenden .deb-Dateien</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[Datei...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Wählen Sie die zu installierenden .deb-Dateien aus</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb-Dateien (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Keine .deb-Dateien standen zur Verfügung.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Datei %1 nicht gefunden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Datei %1 ist keine .deb-Datei.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Diese Anwendung muss als normaler Benutzer ausgeführt werden.</translation>
    </message>
</context>
</TS>

==> deb-installer_25.4.01.tar.xz: BUILD/translations/deb-installer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="112"/>
        <source>Install</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="91"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Die folgenden Pakete werden installiert.
Klicken Sie auf  &apos;Details anzeigen...&apos; für Informationen über die Pakete.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="96"/>
        <source>File: %1</source>
        <translation>Datei: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="110"/>
        <source>Will install the following:</source>
        <translation>Wird das Folgende installieren:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="123"/>
        <source>Installing selected package, please authenticate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../installer.cpp" line="128"/>
        <source>Press any key to close</source>
        <translation>Schließen mit beliebiger Taste</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Programm zur Installation von Debian-Binärpaketen (deb files)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>Dateien...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Name der zu installierenden .deb-Dateien</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[Datei...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Wählen Sie die zu installierenden .deb-Dateien aus</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb-Dateien (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Keine .deb-Dateien standen zur Verfügung.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Datei %1 nicht gefunden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Datei %1 ist keine .deb-Datei.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Diese Anwendung muss als normaler Benutzer ausgeführt werden.</translation>
    </message>
</context>
</TS>
